#
# spec file for package python-libvirt-python
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# No longer build for python2. Support was dropped upstream in the 6.0.0 release
%define skip_python2  1

%{?!python_module:%define python_module() python3-%{**}}
%define srcname libvirt-python
%{?sle15_python_module_pythons}
Name:           python-libvirt-python
URL:            https://libvirt.org/
Version:        9.9.0
Release:        1.1
Summary:        Library providing a virtualization API
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
Source0:        %{srcname}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  libvirt-devel = %{version}
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
%ifpython2
Provides:       libvirt-python = %{version}
Obsoletes:      libvirt-python < %{version}
%endif

%python_subpackages

%description
The python-libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (v2.6.20+).

%prep
%setup -q -n %{srcname}-%{version}

# Unset execute bit for example scripts; it can introduce spurious
# RPM dependencies, like /usr/bin/python which can pull in python2
# for the -python3 package
find examples -type f -exec chmod 0644 \{\} \;

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README COPYING examples/
%{python_sitearch}/libvirt*
%{python_sitearch}/libvirt_python-%{version}*info
%pycache_only %{python_sitearch}/__pycache__/libvirt*

%changelog
* Wed Nov  1 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.9.0
  - Add all new APIs and constants in libvirt 9.9.0
  - jsc#PED-3279, jsc#PED-4931, jsc#PED-5432
* Mon Oct  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.8.0
  - Add all new APIs and constants in libvirt 9.8.0
  - jsc#PED-3279
* Wed Sep  6 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.7.0
  - Add all new APIs and constants in libvirt 9.7.0
  - jsc#PED-3279
* Wed Aug  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.6.0
  - Add all new APIs and constants in libvirt 9.6.0
  - jsc#PED-3725
* Thu Jul  6 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.5.0
  - Add all new APIs and constants in libvirt 9.5.0
* Fri Jun  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.4.0
  - Add all new APIs and constants in libvirt 9.4.0
* Tue May  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.3.0
  - Add all new APIs and constants in libvirt 9.3.0
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Mon Apr  3 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.2.0
  - Add all new APIs and constants in libvirt 9.2.0
* Wed Mar  1 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.1.0
  - Add all new APIs and constants in libvirt 9.1.0
* Tue Jan 17 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.0.0
  - Add all new APIs and constants in libvirt 9.0.0
  - jsc#PED-620
* Thu Dec  1 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.10.0
  - Add all new APIs and constants in libvirt 8.10.0
  - jsc#PED-1472
* Wed Nov  2 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.9.0
  - Add all new APIs and constants in libvirt 8.9.0
  - jsc#PED-620, jsc#PED-1540
* Wed Oct  5 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.8.0
  - Add all new APIs and constants in libvirt 8.8.0
  - jsc#PED-620, jsc#PED-1540
* Thu Sep  1 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.7.0
  - Add all new APIs and constants in libvirt 8.7.0
  - jsc#PED-620, jsc#PED-1540
* Tue Aug  2 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.6.0
  - Add all new APIs and constants in libvirt 8.6.0
* Tue Jul  5 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.5.0
  - Add all new APIs and constants in libvirt 8.5.0
* Wed Jun  1 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.4.0
  - Add all new APIs and constants in libvirt 8.4.0
* Mon May  9 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.3.0
  - Add all new APIs and constants in libvirt 8.3.0
* Fri Apr  1 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.2.0
  - Add all new APIs and constants in libvirt 8.2.0
* Thu Mar  3 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.1.0
  - Add all new APIs and constants in libvirt 8.1.0
* Tue Jan 18 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.0.0
  - Add all new APIs and constants in libvirt 8.0.0
  - jsc#SLE-11435, jsc#SLE-18354
* Thu Dec  2 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.10.0
  - Add all new APIs and constants in libvirt 7.10.0
  - jsc#SLE-18260, jsc#SLE-19264
* Thu Nov  4 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.9.0
  - Add all new APIs and constants in libvirt 7.9.0
  - jsc#SLE-19264
* Fri Oct  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.8.0
  - Add all new APIs and constants in libvirt 7.8.0
  - jsc#SLE-18260
* Wed Sep  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.7.0
  - Add all new APIs and constants in libvirt 7.7.0
  - jsc#SLE-18446
* Mon Aug  2 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.6.0
  - Add all new APIs and constants in libvirt 7.6.0
  - jsc#SLE-18354
* Thu Jul  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.5.0
  - Add all new APIs and constants in libvirt 7.5.0
* Tue Jun  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.4.0
  - Add all new APIs and constants in libvirt 7.4.0
* Mon May 17 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.3.0
  - Add all new APIs and constants in libvirt 7.3.0
* Thu Apr  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.2.0
  - Add all new APIs and constants in libvirt 7.2.0
* Tue Mar  2 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.1.0
  - Add all new APIs and constants in libvirt 7.1.0
* Tue Jan 19 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.0.0
  - Add all new APIs and constants in libvirt 7.0.0
  - jsc#SLE-15860
* Wed Dec  2 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.10.0
  - Add all new APIs and constants in libvirt 6.10.0
  - jsc#SLE-13688
* Mon Nov  2 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.9.0
  - Add all new APIs and constants in libvirt 6.9.0
  - jsc#SLE-13688, jsc#SLE-16754
  - Dropped patches:
    61341150-fix-constructor-param-name.patch
- Add new file _service for tar_scm source service
- Remove signature file and python-libvirt-python.keyring
* Fri Oct 23 2020 Benjamin Greiner <code@bnavigator.de>
- Use %%pycache_only %%python_sitelib instead of %%python3_sitelib in
  order to support multiple python3 flavors
  gh#openSUSE/python-rpm-macros#66
- Enable test suite. It is mandatory for python packages and
  upstream's next major version update will have more tests.
* Mon Oct 12 2020 James Fehlig <jfehlig@suse.com>
- fix constructor param name for virDomain{Checkpoint,Snapshot}
  61341150-fix-constructor-param-name.patch
  boo#1177559
* Thu Oct  1 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.8.0
  - Add all new APIs and constants in libvirt 6.8.0
  - jsc#SLE-12684, jsc#SLE-15861
* Tue Sep  1 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.7.0
  - Add all new APIs and constants in libvirt 6.7.0
  - jsc#SLE-14253, jsc#SLE-15159
* Wed Aug  5 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.6.0
  - Add all new APIs and constants in libvirt 6.6.0
* Mon Jul  6 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.5.0
  - Add all new APIs and constants in libvirt 6.5.0
* Tue Jun  2 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.4.0
  - Add all new APIs and constants in libvirt 6.4.0
* Wed May  6 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.3.0
  - Add all new APIs and constants in libvirt 6.3.0
* Mon Apr  6 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.2.0
  - Add all new APIs and constants in libvirt 6.2.0
* Tue Mar 10 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.1.0
  - Add all new APIs and constants in libvirt 6.1.0
* Thu Feb  6 2020 James Fehlig <jfehlig@suse.com>
- Stop building for python2
  Dropped patches: revert-b22e4f24.patch
* Wed Jan 15 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.0.0
  - Add all new APIs and constants in libvirt 6.0.0
  - Revert commit b22e4f24 to retain python2 support a bit longer
    on SUSE
    revert-b22e4f24.patch
* Mon Dec  2 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.10.0
  - Add all new APIs and constants in libvirt 5.10.0
* Wed Nov  6 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.9.0
  - Add all new APIs and constants in libvirt 5.9.0
* Thu Oct 10 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.8.0
  - Add all new APIs and constants in libvirt 5.8.0
* Thu Sep  5 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.7.0
  - Add all new APIs and constants in libvirt 5.7.0
* Mon Aug 12 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.6.0
  - Add all new APIs and constants in libvirt 5.6.0
* Wed Jul 24 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.5.0
  - Add all new APIs and constants in libvirt 5.5.0
* Mon Jun  3 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.4.0
  - Add all new APIs and constants in libvirt 5.4.0
* Wed May  8 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.3.0
  - Add all new APIs and constants in libvirt 5.3.0
* Wed Apr  3 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.2.0
  - Add all new APIs and constants in libvirt 5.2.0
* Wed Mar  6 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.1.0
  - Add all new APIs and constants in libvirt 5.1.0
  - jsc#SLE-3887, jsc#SLE-4480, jsc#SLE-4577
* Tue Jan 22 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.0.0
  - Add all new APIs and constants in libvirt 5.0.0
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Tue Dec  4 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.10.0
  - Add all new APIs and constants in libvirt 4.10.0
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Mon Nov  5 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.9.0
  - Add all new APIs and constants in libvirt 4.9.0
  - FATE#326371
* Tue Oct  2 2018 jfehlig@suse.com
- Update to 4.8.0
  - Add all new APIs and constants in libvirt 4.8.0
* Thu Sep 20 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.7.0
  - Add all new APIs and constants in libvirt 4.7.0
* Mon Aug 13 2018 jfehlig@suse.com
- Update to 4.6.0
  - Add all new APIs and constants in libvirt 4.6.0
- spec: remove %%defattr
* Fri Jul 27 2018 jfehlig@suse.com
- Update to 4.5.0
  - Add all new APIs and constants in libvirt 4.5.0
* Mon Jun  4 2018 jfehlig@suse.com
- Update to 4.4.0
  - Add all new APIs and constants in libvirt 4.4.0
* Wed May  2 2018 jfehlig@suse.com
- Update to 4.3.0
  - Add all new APIs and constants in libvirt 4.3.0
* Thu Apr  5 2018 jfehlig@suse.com
- Update to 4.2.0
  - Add all new APIs and constants in libvirt 4.2.0
* Mon Mar  5 2018 jfehlig@suse.com
- Update to 4.1.0
  - Add all new APIs and constants in libvirt 4.1.0
* Fri Jan 19 2018 jfehlig@suse.com
- Update to 4.0.0
  - Add all new APIs and constants in libvirt 4.0.0
  - BuildRequire matching libvirt version
* Mon Dec 11 2017 jfehlig@suse.com
- Update to 3.10.0
  - Add all new APIs and constants in libvirt 3.10.0
* Wed Nov 29 2017 cbosdonnat@suse.com
- Get rid of python2 dependency on python3 package
* Thu Nov  2 2017 jfehlig@suse.com
- Update to 3.9.0
  - Add all new APIs and constants in libvirt 3.9.0
* Thu Oct  5 2017 jfehlig@suse.com
- Update to 3.8.0
  - Add all new APIs and constants in libvirt 3.8.0
* Mon Oct  2 2017 jengelh@inai.de
- Rectify RPM group. Adjust descriptions for neutrality and
  OS relevance.
* Fri Sep 15 2017 jfehlig@suse.com
- Update to 3.7.0
  - Add all new APIs and constants in libvirt 3.7.0
* Wed Sep 13 2017 tbechtold@suse.com
- Only the python2 package should provide libvirt-python .
* Wed Aug  2 2017 jfehlig@suse.com
- Update to 3.6.0
  - Add all new APIs and constants in libvirt 3.6.0
* Tue Jul 25 2017 jfehlig@suse.com
- Rename libvirt-python to python-libvirt-python
- Convert to singlespec to support multiple pythons
* Thu Jul  6 2017 jfehlig@suse.com
- Update to 3.5.0
  - Add all new APIs and constants in libvirt 3.5.0
* Fri Jun  2 2017 jfehlig@suse.com
- Update to 3.4.0
  - Add all new APIs and constants in libvirt 3.4.0
* Mon May  8 2017 jfehlig@suse.com
- Update to 3.3.0
  - Add all new APIs and constants in libvirt 3.3.0
  - FATE#319684, FATE#321335, FATE#321349
* Mon Apr  3 2017 jfehlig@suse.com
- Update to 3.2.0
  - Add all new APIs and constants in libvirt 3.2.0
  - FATE#319684, FATE#321335, FATE#321349
* Fri Mar  3 2017 jfehlig@suse.com
- Update to 3.1.0
  - Add all new APIs and constants in libvirt 3.1.0
* Thu Feb  2 2017 jfehlig@suse.com
- SLE12 SP2 FATEs merged via version updates of the Factory
  libvirt-python package:
  FATE#316228, FATE#316628, FATE#319531, FATE#319810, FATE#320490
- SLE12 SP1 FATEs merged via version updates of the Factory
  libvirt-python package:
  FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Thu Jan 19 2017 jfehlig@suse.com
- Update to 3.0.0
  - Add all new APIs and constants in libvirt 3.0.0
* Tue Dec  6 2016 jfehlig@suse.com
- Update to 2.5.0
  - Add all new APIs and constants in libvirt 2.5.0
* Wed Nov  2 2016 jfehlig@suse.com
- Update to 2.4.0
  - Add all new APIs and constants in libvirt 2.4.0
* Wed Oct  5 2016 jfehlig@suse.com
- Update to 2.3.0
  - Add all new APIs and constants in libvirt 2.3.0
- spec: drop explicit Requires on libvirt-client package
* Tue Sep  6 2016 jfehlig@suse.com
- Update to 2.2.0
  - Add all new APIs and constants in libvirt 2.2.0
* Sat Aug 20 2016 jfehlig@suse.com
- Update to 2.1.0
  - Add all new APIs and constants in libvirt 2.1.0
* Fri Jul  1 2016 jfehlig@suse.com
- Update to 2.0.0
  - Add all new APIs and constants in libvirt 2.0.0
* Tue Jun  7 2016 jfehlig@suse.com
- Update to 1.3.5
  - Add all new APIs and constants in libvirt 1.3.5
* Tue May  3 2016 jfehlig@suse.com
- Update to 1.3.4
  - Add all new APIs and constants in libvirt 1.3.4
* Tue Apr 12 2016 jfehlig@suse.com
- Update to 1.3.3
  - Add all new APIs and constants in libvirt 1.3.3
* Tue Mar  1 2016 jfehlig@suse.com
- Update to 1.3.2
  - Add all new APIs and constants in libvirt 1.3.2
* Mon Jan 18 2016 jfehlig@suse.com
- Update to 1.3.1
  - Add all new APIs and constants in libvirt 1.3.1
* Thu Jan  7 2016 jfehlig@suse.com
- Require libvirt-client version >= libvirt-python version
* Mon Dec 21 2015 jfehlig@suse.com
- Update to 1.3.0
  - Add all new APIs and constants in libvirt 1.3.0
* Thu Nov  5 2015 jfehlig@suse.com
- Update to 1.2.21
  - Add all new APIs and constants in libvirt 1.2.21
* Fri Oct  2 2015 jfehlig@suse.com
- Update to 1.2.20
  - Add all new APIs and constants in libvirt 1.2.20
* Wed Sep  2 2015 jfehlig@suse.com
- Update to 1.2.19
  - Add all new APIs and constants in libvirt 1.2.19
* Tue Aug  4 2015 jfehlig@suse.com
- Update to 1.2.18
  - Add all new APIs and constants in libvirt 1.2.18
* Thu Jul  2 2015 jfehlig@suse.com
- Update to 1.2.17
  - Add all new APIs and constants in libvirt 1.2.17
* Mon Jun  1 2015 jfehlig@suse.com
- Update to 1.2.16
  - Add all new APIs and constants in libvirt 1.2.16
* Mon May  4 2015 jfehlig@suse.com
- Update to 1.2.15
  - Add all new APIs and constants in libvirt 1.2.15
* Thu Apr  2 2015 jfehlig@suse.com
- Update to 1.2.14
  - Add all new APIs and constants in libvirt 1.2.14
* Mon Mar  2 2015 jfehlig@suse.com
- Update to 1.2.13
  - Add all new APIs and constants in libvirt 1.2.13
* Tue Jan 27 2015 jfehlig@suse.com
- Update to 1.2.12
  - Add all new APIs and constants in libvirt 1.2.12
* Mon Dec 15 2014 jfehlig@suse.com
- Update to 1.2.11
  - Add all new APIs and constants in libvirt 1.2.11
* Mon Nov  3 2014 jfehlig@suse.com
- Update to 1.2.10
  - Add all new APIs and constants in libvirt 1.2.10
* Thu Oct  2 2014 jfehlig@suse.com
- spec: Remove gpg-offline build dependency and use of gpg_verify
  to verify tarball since this task can be performed by source
  services
* Wed Oct  1 2014 jfehlig@suse.com
- Update to 1.2.9
  - Add all new APIs and constants in libvirt 1.2.9
- Verify tarball using %%gpg_verify using associated .asc file
  Add: libvirt-python.keyring, libvirt-python-1.2.9.tar.gz.asc
  Use upstream .gz tarball instead of locally generated .bz2
* Tue Sep  2 2014 jfehlig@suse.com
- Update to 1.2.8
  - Add all new APIs and constants in libvirt 1.2.8
* Tue Aug  5 2014 jfehlig@suse.com
- Update to 1.2.7
  - Add all new APIs and constants in libvirt 1.2.7
* Wed Jul  2 2014 jfehlig@suse.com
- Update to 1.2.6
  - Add all new APIs and constants in libvirt 1.2.6
* Mon Jun  2 2014 jfehlig@suse.com
- Update to 1.2.5
  - Add all new APIs and constants in libvirt 1.2.5
* Tue May  6 2014 jfehlig@suse.com
- Update to 1.2.4
  - Add all new APIs and constants in libvirt 1.2.4
* Mon Apr  7 2014 jfehlig@suse.com
- Update to 1.2.3
  - Add all new APIs and constants in libvirt 1.2.3
* Mon Mar  3 2014 jfehlig@suse.com
- Update to 1.2.2
  - Add all new APIs and constants in libvirt 1.2.2
* Fri Jan 17 2014 jfehlig@suse.com
- Update to 1.2.1
  - Add all new APIs and constants in libvirt 1.2.1
* Mon Dec  9 2013 jfehlig@suse.com
- Add missing BuildRoot definition
* Mon Dec  9 2013 speilicke@suse.com
- Fix macro usage (Build on SLE)
- Don't rm *.egg-info
- No need for CFLAGS
* Wed Dec  4 2013 jfehlig@suse.com
- Initial packaging of libvirt python bindings after being split
  out of libvirt.git.  The libvirt python bindings are now separate
  from libvirt and maintained in git://libvirt.org/libvirt-python.git
